"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _bluebirdLst;

function _load_bluebirdLst() {
    return _bluebirdLst = require("bluebird-lst");
}

var _s;

function _load_s() {
    return _s = _interopRequireDefault(require("aws-sdk/clients/s3"));
}

var _builderUtil;

function _load_builderUtil() {
    return _builderUtil = require("builder-util");
}

var _BaseS3Publisher;

function _load_BaseS3Publisher() {
    return _BaseS3Publisher = require("./BaseS3Publisher");
}

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class S3Publisher extends (_BaseS3Publisher || _load_BaseS3Publisher()).BaseS3Publisher {
    constructor(context, info) {
        super(context, info);
        this.info = info;
        this.providerName = "S3";
    }
    static checkAndResolveOptions(options, channelFromAppVersion) {
        return (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* () {
            const bucket = options.bucket;
            if (bucket == null) {
                throw new (_builderUtil || _load_builderUtil()).InvalidConfigurationError(`Please specify "bucket" for "s3" publish provider`);
            }
            if (options.endpoint == null && bucket.includes(".") && options.region == null) {
                // on dotted bucket names, we need to use a path-based endpoint URL. Path-based endpoint URLs need to include the region.
                const s3 = new (_s || _load_s()).default({ signatureVersion: "v4" });
                options.region = (yield s3.getBucketLocation({ Bucket: bucket }).promise()).LocationConstraint;
            }
            if (options.channel == null && channelFromAppVersion != null) {
                options.channel = channelFromAppVersion;
            }
        })();
    }
    createClientConfiguration() {
        const configuration = super.createClientConfiguration();
        const endpoint = this.info.endpoint;
        if (endpoint != null) {
            configuration.endpoint = endpoint;
            configuration.s3ForcePathStyle = true;
        }
        return configuration;
    }
    getBucketName() {
        return this.info.bucket;
    }
    configureS3Options(s3Options) {
        super.configureS3Options(s3Options);
        if (this.info.storageClass != null) {
            s3Options.StorageClass = this.info.storageClass;
        }
        if (this.info.encryption != null) {
            s3Options.ServerSideEncryption = this.info.encryption;
        }
    }
    toString() {
        const result = super.toString();
        const endpoint = this.info.endpoint;
        if (endpoint != null) {
            return result.substring(0, result.length - 1) + `, endpoint: ${endpoint})`;
        }
        return result;
    }
}
exports.default = S3Publisher; //# sourceMappingURL=s3Publisher.js.map